import org.ergoplatform.mining.emission
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.mining")``.

    emission: org.ergoplatform.mining.emission.__module_protocol__
