import org.ergoplatform.explorer.client
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.explorer")``.

    client: org.ergoplatform.explorer.client.__module_protocol__
