import retrofit2.converter.gson
import retrofit2.converter.scalars
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("retrofit2.converter")``.

    gson: retrofit2.converter.gson.__module_protocol__
    scalars: retrofit2.converter.scalars.__module_protocol__
