import java.applet
import java.awt
import java.beans
import java.io
import java.lang
import java.math
import java.net
import java.nio
import java.rmi
import java.security
import java.sql
import java.text
import java.time
import java.util
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java")``.

    applet: java.applet.__module_protocol__
    awt: java.awt.__module_protocol__
    beans: java.beans.__module_protocol__
    io: java.io.__module_protocol__
    lang: java.lang.__module_protocol__
    math: java.math.__module_protocol__
    net: java.net.__module_protocol__
    nio: java.nio.__module_protocol__
    rmi: java.rmi.__module_protocol__
    security: java.security.__module_protocol__
    sql: java.sql.__module_protocol__
    text: java.text.__module_protocol__
    time: java.time.__module_protocol__
    util: java.util.__module_protocol__
