import java.lang
import org.ergoplatform.appkit.cli
import org.ergoplatform.appkit.commands
import org.ergoplatform.appkit.config
import scala
import scala.collection
import typing



class HelpCmd(org.ergoplatform.appkit.commands.Cmd, scala.Product, scala.Serializable):
    def __init__(self, toolConf: org.ergoplatform.appkit.config.ErgoToolConfig, name: typing.Union[java.lang.String, str], askedCmd: typing.Union[java.lang.String, str]): ...
    @staticmethod
    def BaseDocUrl() -> java.lang.String: ...
    @staticmethod
    def apply(toolConf: org.ergoplatform.appkit.config.ErgoToolConfig, name: typing.Union[java.lang.String, str], askedCmd: typing.Union[java.lang.String, str]) -> 'HelpCmd': ...
    def askedCmd(self) -> java.lang.String: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    @staticmethod
    def cmdParamSyntax() -> java.lang.String: ...
    def copy(self, toolConf: org.ergoplatform.appkit.config.ErgoToolConfig, name: typing.Union[java.lang.String, str], askedCmd: typing.Union[java.lang.String, str]) -> 'HelpCmd': ...
    def copy$default$1(self) -> org.ergoplatform.appkit.config.ErgoToolConfig: ...
    def copy$default$2(self) -> java.lang.String: ...
    def copy$default$3(self) -> java.lang.String: ...
    @staticmethod
    def createCmd(ctx: org.ergoplatform.appkit.cli.AppContext) -> org.ergoplatform.appkit.commands.Cmd: ...
    @staticmethod
    def description() -> java.lang.String: ...
    @staticmethod
    def docUrl() -> java.lang.String: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def name(self) -> java.lang.String: ...
    @staticmethod
    def parameters() -> scala.collection.Seq[org.ergoplatform.appkit.commands.CmdParameter]: ...
    @staticmethod
    def parseArgs(ctx: org.ergoplatform.appkit.cli.AppContext, args: scala.collection.Seq[typing.Union[java.lang.String, str]]) -> scala.collection.Seq[typing.Any]: ...
    @staticmethod
    def printUsage(console: org.ergoplatform.appkit.cli.Console) -> org.ergoplatform.appkit.cli.Console: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def run(self, ctx: org.ergoplatform.appkit.cli.AppContext) -> None: ...
    def toString(self) -> java.lang.String: ...
    def toolConf(self) -> org.ergoplatform.appkit.config.ErgoToolConfig: ...
    @staticmethod
    def unapply(x$0: 'HelpCmd') -> scala.Option[scala.Tuple3[org.ergoplatform.appkit.config.ErgoToolConfig, java.lang.String, java.lang.String]]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.appkit.ergotool")``.

    HelpCmd: typing.Type[HelpCmd]
