import scorex.crypto.authds.avltree.batch
import typing



class package:
    @staticmethod
    def LabelOfNone() -> typing.List[int]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scorex.crypto.authds.avltree")``.

    package: typing.Type[package]
    batch: scorex.crypto.authds.avltree.batch.__module_protocol__
