import scorex.crypto.authds.legacy.avltree
import scorex.crypto.authds.legacy.treap
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scorex.crypto.authds.legacy")``.

    avltree: scorex.crypto.authds.legacy.avltree.__module_protocol__
    treap: scorex.crypto.authds.legacy.treap.__module_protocol__
