import org.ergoplatform
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org")``.

    ergoplatform: org.ergoplatform.__module_protocol__
